==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_account/paginator.py <==
"""
Type annotations for account service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_account.client import AccountClient
    from types_boto3_account.paginator import (
        ListRegionsPaginator,
    )

    session = Session()
    client: AccountClient = session.client("account")

    list_regions_paginator: ListRegionsPaginator = client.get_paginator("list_regions")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListRegionsRequestListRegionsPaginateTypeDef, ListRegionsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRegionsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListRegionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account/paginator/ListRegions.html#Account.Paginator.ListRegions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/#listregionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListRegionsRequestListRegionsPaginateTypeDef]
    ) -> _PageIterator[ListRegionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account/paginator/ListRegions.html#Account.Paginator.ListRegions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/#listregionspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_account/paginator.py <==
"""
Type annotations for account service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_account.client import AccountClient
    from types_boto3_account.paginator import (
        ListRegionsPaginator,
    )

    session = Session()
    client: AccountClient = session.client("account")

    list_regions_paginator: ListRegionsPaginator = client.get_paginator("list_regions")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListRegionsRequestPaginateTypeDef, ListRegionsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRegionsPaginator",)


if TYPE_CHECKING:
    _ListRegionsPaginatorBase = Paginator[ListRegionsResponseTypeDef]
else:
    _ListRegionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListRegionsPaginator(_ListRegionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account/paginator/ListRegions.html#Account.Paginator.ListRegions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/#listregionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRegionsRequestPaginateTypeDef]
    ) -> PageIterator[ListRegionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account/paginator/ListRegions.html#Account.Paginator.ListRegions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_account/paginators/#listregionspaginator)
        """
